@@ -41,7 +41,10 @@ def generate_actions_from_irc_message(args,printer):
 
     monitoring_channel = monitored_channel( channel, monitored_channels )
     if not to_me and not from_me and channel == "test":
-        printer("Monitoring channel" + channel, str(Monitoring_channel))
+        printer("Monitoring channel" + channel, str(monitoring_channel))
+
+    if debug:
+        printer("to_me: " + to_me + ", from_me: " + from_me + ", monitoring_channel: " + monitoring_channel,"")
 
     if not to_me and not from_me and monitoring_channel:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
